@@ -4,6 +4,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 from os import sep
 from os.path import exists, join, dirname
+import sys
 from six.moves.configparser import (  # pylint: disable=import-error
     ConfigParser,
     NoSectionError,
@@ -44,6 +45,16 @@ class ProgrammaticReporter(BaseReporter):
     def _display(self, layout):
         """launch layouts display"""
 
+    def on_set_current_module(self, module, filepath):
+        """Hook called when a module starts to be analysed."""
+        print('.', end='')
+        sys.stdout.flush()
+
+    def on_close(self, stats, previous_stats):
+        """Hook called when all modules finished analyzing."""
+        # print a new line when pylint is finished
+        print('')
+
 
 def get_rel_path(path, parent_path):
     """
@@ -65,6 +76,12 @@ def pytest_addoption(parser):
         action="store_true", default=False,
         help="run pylint on all"
     )
+    group.addoption(
+        "--no-pylint",
+        action="store_true", default=False,
+        help="disable running pylint "
+    )
+
     group.addoption(
         '--pylint-rcfile',
         default=None,
@@ -120,21 +137,22 @@ def pytest_sessionstart(session):
 
 def pytest_collect_file(path, parent):
     """Collect files on which pylint should run"""
-    config = parent.config
-    if not config.option.pylint:
+    config = parent.session.config
+    if not config.option.pylint or config.option.no_pylint:
         return None
     if path.ext != ".py":
         return None
-    rel_path = get_rel_path(path.strpath, parent.fspath.strpath)
-    if parent.pylint_config is None:
-        parent.pylint_files.add(rel_path)
+    rel_path = get_rel_path(path.strpath, parent.session.fspath.strpath)
+    session = parent.session
+    if session.pylint_config is None:
+        session.pylint_files.add(rel_path)
         # No pylintrc, therefore no ignores, so return the item.
         return PyLintItem(path, parent)
 
-    if not any(basename in rel_path for basename in parent.pylint_ignore):
-        parent.pylint_files.add(rel_path)
+    if not any(basename in rel_path for basename in session.pylint_ignore):
+        session.pylint_files.add(rel_path)
         return PyLintItem(
-            path, parent, parent.pylint_msg_template, parent.pylintrc_file
+            path, parent, session.pylint_msg_template, session.pylintrc_file
         )
     return None
 
@@ -157,8 +175,14 @@ def pytest_collection_finish(session):
         args_list.append(jobs)
     print('-' * 65)
     print('Linting files')
+    # Disabling keyword arg to handle both 1.x and 2.x pylint API calls
+    # pylint: disable=unexpected-keyword-arg
+
     # Run pylint over the collected files.
-    result = lint.Run(args_list, reporter=reporter, exit=False)
+    try:
+        result = lint.Run(args_list, reporter=reporter, exit=False)
+    except TypeError:  # Handle pylint 2.0 API
+        result = lint.Run(args_list, reporter=reporter, do_exit=False)
     messages = result.linter.reporter.data
     # Stores the messages in a dictionary for lookup in tests.
     for message in messages:
@@ -173,12 +197,15 @@ class PyLintItem(pytest.Item, pytest.File):
     # pylint doesn't deal well with dynamic modules and there isn't an
     # astng plugin for pylint in pypi yet, so we'll have to disable
     # the checks.
-    # pylint: disable=no-member,super-on-old-class
+    # pylint: disable=no-member,super-on-old-class,abstract-method
     def __init__(self, fspath, parent, msg_format=None, pylintrc_file=None):
         super(PyLintItem, self).__init__(fspath, parent)
 
         self.add_marker("pylint")
-        self.rel_path = get_rel_path(fspath.strpath, parent.fspath.strpath)
+        self.rel_path = get_rel_path(
+            fspath.strpath,
+            parent.session.fspath.strpath
+        )
 
         if msg_format is None:
             self._msg_format = '{C}:{line:3d},{column:2d}: {msg} ({symbol})'
@@ -206,4 +233,4 @@ class PyLintItem(pytest.Item, pytest.File):
 
     def reportinfo(self):
         """Generate our test report"""
-        return self.fspath, None, "[pylint] {0}".format(self.name)
+        return self.fspath, None, "[pylint] {0}".format(self.rel_path)
